==> pitaya-framework-0.0.2.tgz: package/src/app-configuration.ts <==
import { IAppConfig }              from "../index";
import { executeDevelopmentQueue } from "./development";

interface IPitayaAppConfiguration extends IAppConfig
{
	set( settings: object );
}

export const PitayaAppConfiguration: IPitayaAppConfiguration = {
	Components  : {},
	Development : {
		enabled                 : false as boolean,
		bodyClassName           : "pitaya--under-development" as string,
		disablePrivateRedirects : false as boolean
	},
	User        : {
		useLogin    : false as boolean,
		defaultView : "default" as string
	},
	View        : {
		privateRedirectView : "" as string,
		defaultTheme        : "primary" as string
	},
	Database    : {
		userNameFieldName     : "name",
		settingsNameFieldName : "name",
		userIdFieldName       : "pitaya_user_id",
		settingsIdFieldName   : "pitaya_settings_id"
	},
	Custom      : {},
	set( settings: object ): Promise<void>
	{
		if( typeof settings !== "object" )
		{
			return;
		}

		_replaceRecursive( settings, PitayaAppConfiguration );

		delete PitayaAppConfiguration.set;

		Object.freeze( PitayaAppConfiguration );

		return executeDevelopmentQueue( PitayaAppConfiguration );
	}
};

const _replaceRecursive = function( source, target )
{
	for( const key in source )
	{
		const setting = source[ key ];

		if( key !== "Custom" && ( !target.hasOwnProperty( key ) || typeof setting !== typeof target[ key ] ) )
		{
			continue;
		}

		/* If not object */
		// @ts-ignore
		if( ( typeof setting !== "object" && !source[ Symbol.iterator ] ) || key === "Custom" )
		{
			target[ key ] = setting;

			continue;
		}

		_replaceRecursive( setting, target[ key ] );
	}
};

==> pitaya-framework-0.0.5.tgz: package/src/app-configuration.ts <==
import { IAppConfig }              from "../interfaces.d";
import { executeDevelopmentQueue } from "./development";

interface IPitayaAppConfiguration extends IAppConfig
{
	set( settings: object );
}

export const PitayaAppConfiguration: IPitayaAppConfiguration = {
	Components  : {},
	Development : {
		enabled                 : false as boolean,
		bodyClassName           : "pitaya--under-development" as string,
		disablePrivateRedirects : false as boolean
	},
	User        : {
		useLogin    : false as boolean,
		defaultView : "default" as string
	},
	View        : {
		privateRedirectView : "" as string,
		defaultTheme        : "primary" as string
	},
	Database    : {
		userNameFieldName    : "name",
		storageNameFieldName : "name",
		userIdFieldName      : "pitaya_user_id",
		storageIdFieldName   : "pitaya_storage_id"
	},
	Custom      : {},
	set( settings: object ): Promise<void>
	{
		if( typeof settings !== "object" )
		{
			return;
		}

		_replaceRecursive( settings, PitayaAppConfiguration );

		delete PitayaAppConfiguration.set;

		Object.freeze( PitayaAppConfiguration );

		return executeDevelopmentQueue( PitayaAppConfiguration );
	}
};

const _replaceRecursive = function( source, target )
{
	for( const key in source )
	{
		const setting = source[ key ];

		if( key !== "Custom" && ( !target.hasOwnProperty( key ) || typeof setting !== typeof target[ key ] ) )
		{
			continue;
		}

		/* If not object */
		// @ts-ignore
		if( ( typeof setting !== "object" && !source[ Symbol.iterator ] ) || key === "Custom" )
		{
			target[ key ] = setting;

			continue;
		}

		_replaceRecursive( setting, target[ key ] );
	}
};
